<?php

namespace FiloBlu\PaymentMethodFilter\Model;

use FiloBlu\PaymentMethodFilter\Api\CartManagementInterface;
use FiloBlu\PaymentMethodFilter\Helper\PaymentFilter as Helper;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Quote\Api\CartRepositoryInterface;
use Magento\Quote\Model\MaskedQuoteIdToQuoteIdInterface;

/**
 * Class CartManagement
 * @package FiloBlu\PaymentMethodFilter\Model
 */
class CartManagement implements CartManagementInterface
{

    /**
     * @var Helper
     */
    private $helper;
    /**
     * @var CartRepositoryInterface
     */
    private $quoteRepository;

    /**
     * @var MaskedQuoteIdToQuoteIdInterface
     */
    private $maskedQuoteIdToQuoteId;

    /**
     * @param Helper $helper
     * @param CartRepositoryInterface $quoteRepository
     */
    public function __construct(
        Helper                          $helper,
        CartRepositoryInterface         $quoteRepository,
        MaskedQuoteIdToQuoteIdInterface $maskedQuoteIdToQuoteId
    )
    {
        $this->helper = $helper;
        $this->quoteRepository = $quoteRepository;
        $this->maskedQuoteIdToQuoteId = $maskedQuoteIdToQuoteId;
    }

    /**
     * @param string $cartId
     * @return bool|null
     */
    public function onlyGiftcards(string $cartId)
    {

        try {
            if (!is_numeric($cartId)) {
                //the user is guest, so quoteId is masked
                $cartId = $this->maskedQuoteIdToQuoteId->execute($cartId);
            }
            $quote = $this->quoteRepository->getActive($cartId);
            if (!isset($quote)) {
                return false;
            }
            return $this->helper->quoteContainsOnlyGiftcard($quote);

        } catch (NoSuchEntityException $e) {
            throw new LocalizedException(
                __('Could not find a cart with ID "%quoteId"', ['quoteId' => $cartId])
            );
        }
    }
}